# rbxmx-converter

This is a simple python project to convert RBXMX files saved from Roblox Studio, into a valid file tree that can be used later. Useful for saving files and more or your local computer.